# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-21 12:54
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Translation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='DTST1', null=True, verbose_name='DTSM1')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='DTST2', null=True, verbose_name='DTSM2')),
                ('tag', models.CharField(help_text='DTST8', max_length=20, unique=True, verbose_name='DTSM8')),
                ('text', models.TextField(help_text='DTST9', verbose_name='DTSM9')),
                ('text_en', models.TextField(help_text='DTST9', null=True, verbose_name='DTSM9')),
                ('text_pt_br', models.TextField(help_text='DTST9', null=True, verbose_name='DTSM9')),
                ('auxiliary_tag', models.CharField(blank=True, help_text='DTST10', max_length=20, null=True, verbose_name='DTSM10')),
                ('auxiliary_text', models.TextField(blank=True, help_text='DTST11', null=True, verbose_name='DTSM11')),
                ('auxiliary_text_en', models.TextField(blank=True, help_text='DTST11', null=True, verbose_name='DTSM11')),
                ('auxiliary_text_pt_br', models.TextField(blank=True, help_text='DTST11', null=True, verbose_name='DTSM11')),
                ('migration_created', models.BooleanField(default=False, help_text='DTST12', verbose_name='DTSM12')),
            ],
            options={
                'verbose_name': 'DTSMT2',
                'verbose_name_plural': 'DTSMTP2',
            },
        ),
        migrations.CreateModel(
            name='TranslationType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='DTST1', null=True, verbose_name='DTSM1')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='DTST2', null=True, verbose_name='DTSM2')),
                ('tag', models.CharField(help_text='DTST3', max_length=20, unique=True, verbose_name='DTSM3')),
                ('name', models.TextField(help_text='DTST4', verbose_name='DTSM4')),
                ('name_en', models.TextField(help_text='DTST4', null=True, verbose_name='DTSM4')),
                ('name_pt_br', models.TextField(help_text='DTST4', null=True, verbose_name='DTSM4')),
                ('has_auxiliary_text', models.BooleanField(default=True, help_text='DTST5', verbose_name='DTSM5')),
                ('auxiliary_tag', models.CharField(blank=True, default=False, help_text='DTST6', max_length=20, null=True, unique=True, verbose_name='DTSM6')),
            ],
            options={
                'verbose_name': 'DTSMT1',
                'verbose_name_plural': 'DTSMTP1',
            },
        ),
        migrations.AddField(
            model_name='translation',
            name='type',
            field=models.ForeignKey(help_text='DTST7', on_delete=django.db.models.deletion.CASCADE, related_name='translation_translation_type', to='translation_server.TranslationType', verbose_name='DTSM7'),
        ),
    ]
